Description Usage Arguments Details Value
View source: R/calculate_age.R
Finds out the calendar year difference between two dates.
1 | calculate_age(givendate, birthdate)
|
givendate, birthdate |
Date vectors of equal length. |
For birthdate > givendate NAs are returned .
An integer vector of the same length as givendate.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.